@@ -141,8 +141,8 @@ def _get_network_filter(network_type: str) -> str:
 def _get_overpass_pause(
     base_endpoint: str,
     *,
-    recursive_delay: float = 5,
-    default_duration: float = 60,
+    recursion_pause: float = 5,
+    default_pause: float = 60,
 ) -> float:
     """
     Retrieve a pause duration from the Overpass API status endpoint.
@@ -155,19 +155,19 @@ def _get_overpass_pause(
     ----------
     base_endpoint
         Base Overpass API URL (without "/status" at the end).
-    recursive_delay
+    recursion_pause
         How long to wait between recursive calls if the server is currently
         running a query.
-    default_duration
-        If a fatal error occurs, fall back on returning this value.
+    default_pause
+        If a fatal error occurs, fall back on this liberal pause duration.
 
     Returns
     -------
     pause
         The current pause duration specified by the Overpass status endpoint.
     """
+    # if overpass rate limiting is False, then there is zero pause
     if not settings.overpass_rate_limit:
-        # if overpass rate limiting is False, then there is zero pause
         return 0
 
     url = base_endpoint.rstrip("/") + "/status"
@@ -183,9 +183,9 @@ def _get_overpass_pause(
         response_text = response.text
     except RequestsConnectionError as e:  # pragma: no cover
         # cannot reach status endpoint: log error and return default duration
-        msg = f"Unable to query {url}, {e}"
+        msg = f"Unable to reach {url}, {e}"
         utils.log(msg, level=lg.ERROR)
-        return default_duration
+        return default_pause
 
     # try to parse the output
     try:
@@ -195,7 +195,7 @@ def _get_overpass_pause(
         # cannot parse output: log error and return default duration
         msg = f"Unable to parse {url} response: {response_text}"
         utils.log(msg, level=lg.ERROR)
-        return default_duration
+        return default_pause
 
     # determine the current status of the server
     try:
@@ -209,22 +209,22 @@ def _get_overpass_pause(
         if status_first_part == "Slot":
             utc_time_str = status.split(" ")[3]
             pattern = "%Y-%m-%dT%H:%M:%SZ,"
-            utc_time = dt.datetime.strptime(utc_time_str, pattern).astimezone(dt.timezone.utc)
+            utc_time = dt.datetime.strptime(utc_time_str, pattern).replace(tzinfo=dt.timezone.utc)
             utc_now = dt.datetime.now(tz=dt.timezone.utc)
             seconds = int(np.ceil((utc_time - utc_now).total_seconds()))
             pause = max(seconds, 1)
 
         # if first token is 'Currently', it is currently running a query so
-        # check back in recursive_delay seconds
+        # check back in recursion_pause seconds
         elif status_first_part == "Currently":
-            time.sleep(recursive_delay)
+            time.sleep(recursion_pause)
             pause = _get_overpass_pause(base_endpoint)
 
         # any other status is unrecognized: log error, return default duration
         else:
             msg = f"Unrecognized server status: {status!r}"
             utils.log(msg, level=lg.ERROR)
-            return default_duration
+            return default_pause
 
     return pause
 
@@ -296,6 +296,7 @@ def _create_overpass_features_query(  # noqa: PLR0912
     Returns
     -------
     query
+        The Overpass features query.
     """
     # create overpass settings string
     overpass_settings = _make_overpass_settings()
@@ -427,12 +428,7 @@ def _download_overpass_features(
         yield _overpass_request(OrderedDict(data=query_str))
 
 
-def _overpass_request(
-    data: OrderedDict[str, Any],
-    *,
-    pause: float | None = None,
-    error_pause: float = 60,
-) -> dict[str, Any]:
+def _overpass_request(data: OrderedDict[str, Any]) -> dict[str, Any]:
     """
     Send a HTTP POST request to the Overpass API and return response.
 
@@ -440,16 +436,11 @@ def _overpass_request(
     ----------
     data
         Key-value pairs of parameters.
-    pause
-        How long to pause in seconds before request. If None, will query API
-        status endpoint to find when next slot is available.
-    error_pause
-        How long to pause in seconds (in addition to `pause`) before re-trying
-        request if error.
 
     Returns
     -------
     response_json
+        The Overpass API's response.
     """
     # resolve url to same IP even if there is server round-robin redirecting
     _http._config_dns(settings.overpass_url)
@@ -462,12 +453,11 @@ def _overpass_request(
         return cached_response_json
 
     # pause then request this URL
-    if pause is None:
-        this_pause = _get_overpass_pause(settings.overpass_url)
+    pause = _get_overpass_pause(settings.overpass_url)
     hostname = _http._hostname_from_url(url)
-    msg = f"Pausing {this_pause} second(s) before making HTTP POST request to {hostname!r}"
+    msg = f"Pausing {pause} second(s) before making HTTP POST request to {hostname!r}"
     utils.log(msg, level=lg.INFO)
-    time.sleep(this_pause)
+    time.sleep(pause)
 
     # transmit the HTTP POST request
     msg = f"Post {prepared_url} with timeout={settings.requests_timeout}"
@@ -482,14 +472,14 @@ def _overpass_request(
 
     # handle 429 and 504 errors by pausing then recursively re-trying request
     if response.status_code in {429, 504}:  # pragma: no cover
-        this_pause = error_pause + _get_overpass_pause(settings.overpass_url)
+        error_pause = 55
         msg = (
             f"{hostname!r} responded {response.status_code} {response.reason}: "
-            f"we'll retry in {this_pause} secs"
+            f"we'll retry in {error_pause} secs"
         )
         utils.log(msg, level=lg.WARNING)
-        time.sleep(this_pause)
-        return _overpass_request(data, pause=pause, error_pause=error_pause)
+        time.sleep(error_pause)
+        return _overpass_request(data)
 
     response_json = _http._parse_response(response)
     if not isinstance(response_json, dict):  # pragma: no cover
