@@ -223,11 +223,6 @@ def _validate_node_edge_gdfs(
         GeoDataFrame of graph nodes uniquely indexed by `osmid`.
     gdf_edges
         GeoDataFrame of graph edges uniquely multi-indexed by `(u, v, key)`.
-    graph_attrs
-
-    Returns
-    -------
-    None
     """
     # ensure gdf_nodes contains x and y columns representing node geometries
     if not ("x" in gdf_nodes.columns and "y" in gdf_nodes.columns):  # pragma: no cover
@@ -302,6 +297,7 @@ def graph_from_gdfs(
     Returns
     -------
     G
+        The converted MultiDiGraph.
     """
     _validate_node_edge_gdfs(gdf_nodes, gdf_edges)
 
@@ -354,7 +350,8 @@ def to_digraph(G: nx.MultiDiGraph, *, weight: str = "length") -> nx.DiGraph:
 
     Returns
     -------
-    G
+    D
+        The converted DiGraph.
     """
     # make a copy to not mutate original graph object caller passed in
     G = G.copy()
@@ -397,6 +394,7 @@ def to_undirected(G: nx.MultiDiGraph) -> nx.MultiGraph:
     Returns
     -------
     Gu
+        The converted MultiGraph.
     """
     # make a copy to not mutate original graph object caller passed in
     G = G.copy()
@@ -460,6 +458,7 @@ def _is_duplicate_edge(data1: dict[str, Any], data2: dict[str, Any]) -> bool:
     Returns
     -------
     is_dupe
+        True if `osmid` and `geometry` are the same, otherwise False.
     """
     is_dupe = False
 
@@ -502,6 +501,7 @@ def _is_same_geometry(ls1: LineString, ls2: LineString) -> bool:
     Returns
     -------
     is_same
+        True if geometries are the same in either direction, otherwise False.
     """
     # extract coordinates from each LineString geometry
     geom1 = [tuple(coords) for coords in ls1.xy]
@@ -531,6 +531,7 @@ def _update_edge_keys(G: nx.MultiDiGraph) -> nx.MultiDiGraph:
     Returns
     -------
     G
+        Graph with incremented keys where needed.
     """
     # identify all the edges that are duplicates based on a sorted combination
     # of their origin, destination, and key. that is, edge uv will match edge vu
