@@ -5,7 +5,6 @@ from __future__ import annotations
 import logging as lg
 import multiprocessing as mp
 import time
-from hashlib import sha1
 from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
@@ -128,10 +127,9 @@ def _build_vrt_file(raster_paths: Iterable[str | Path]) -> Path:
         msg = "rio-vrt must be installed as an optional dependency to build VRTs."
         raise ImportError(msg)
 
-    # use the sha1 hash of the sorted filepaths as the VRT filename
+    # determine VRT cache filepath, from stringified sorted raster filepaths
     raster_paths = sorted(raster_paths)
-    checksum = sha1(str(raster_paths).encode("utf-8")).hexdigest()  # noqa: S324
-    vrt_path = Path(settings.cache_folder) / f"{checksum}.vrt"
+    vrt_path = _http._resolve_cache_filepath(str(raster_paths), "vrt")
 
     # build the VRT file if it doesn't already exist in the cache
     if not vrt_path.is_file():
@@ -167,7 +165,9 @@ def add_node_elevations_raster(
     band
         Which raster band to query.
     cpus
-        How many CPU cores to use. If None, use all available.
+        How many CPU cores to use if multiprocessing. If None, use all
+        available. If you are multiprocessing, make sure you protect your
+        entry point: see the Python docs for details.
 
     Returns
     -------
@@ -288,7 +288,7 @@ def add_node_elevations_google(
 
 def _elevation_request(url: str, pause: float) -> dict[str, Any]:
     """
-    Send a HTTP GET request to a Google Maps-style Elevation API.
+    Send a HTTP GET request to a Google Maps-style elevation API.
 
     Parameters
     ----------
@@ -300,6 +300,7 @@ def _elevation_request(url: str, pause: float) -> dict[str, Any]:
     Returns
     -------
     response_json
+        The elevation API's response.
     """
     # check if request already exists in cache
     cached_response_json = _http._retrieve_from_cache(url)
