@@ -1,3 +1,4 @@
+# ruff: noqa: A005
 """File I/O functions to save/load graphs to/from files on disk."""
 
 from __future__ import annotations
@@ -45,10 +46,6 @@ def save_graph_geopackage(
         True, save one edge for each directed edge in the graph.
     encoding
         The character encoding of the saved GeoPackage file.
-
-    Returns
-    -------
-    None
     """
     # default filepath if none was provided
     filepath = Path(settings.data_folder) / "graph.gpkg" if filepath is None else Path(filepath)
@@ -94,10 +91,6 @@ def save_graphml(
         interpretation of the GraphML specification.
     encoding
         The character encoding of the saved GraphML file.
-
-    Returns
-    -------
-    None
     """
     # default filepath if none was provided
     filepath = Path(settings.data_folder) / "graph.graphml" if filepath is None else Path(filepath)
@@ -178,6 +171,7 @@ def load_graphml(
     Returns
     -------
     G
+        The loaded MultiDiGraph.
     """
     if (filepath is None and graphml_str is None) or (
         filepath is not None and graphml_str is not None
@@ -186,7 +180,10 @@ def load_graphml(
         raise ValueError(msg)
 
     # specify default graph/node/edge attribute values' data types
-    default_graph_dtypes = {"simplified": _convert_bool_string}
+    default_graph_dtypes = {
+        "consolidated": _convert_bool_string,
+        "simplified": _convert_bool_string,
+    }
     default_node_dtypes = {
         "elevation": float,
         "elevation_res": float,
@@ -287,10 +284,6 @@ def save_graph_xml(
         attribute will be assigned the value of the first edge of the way.
     encoding
         The character encoding of the saved OSM XML file.
-
-    Returns
-    -------
-    None
     """
     _osm_xml._save_graph_xml(G, filepath, way_tag_aggs, encoding)
 
@@ -309,6 +302,7 @@ def _convert_graph_attr_types(G: nx.MultiDiGraph, dtypes: dict[str, Any]) -> nx.
     Returns
     -------
     G
+        The graph with its graph-level attributes' types converted.
     """
     # remove node_default and edge_default metadata keys if they exist
     G.graph.pop("node_default", None)
@@ -334,6 +328,7 @@ def _convert_node_attr_types(G: nx.MultiDiGraph, dtypes: dict[str, Any]) -> nx.M
     Returns
     -------
     G
+        The graph with its nodes' attributes' types converted.
     """
     for _, data in G.nodes(data=True):
         # first, eval stringified lists, dicts, or sets to convert them to objects
@@ -364,6 +359,7 @@ def _convert_edge_attr_types(G: nx.MultiDiGraph, dtypes: dict[str, Any]) -> nx.M
     Returns
     -------
     G
+        The graph with its edges' attributes' types converted.
     """
     # for each edge in the graph, eval attribute value lists and convert types
     for _, _, data in G.edges(data=True, keys=False):
@@ -410,11 +406,12 @@ def _convert_bool_string(value: bool | str) -> bool:
     Parameters
     ----------
     value
-        The string value to convert to bool.
+        The string to convert to bool.
 
     Returns
     -------
     bool_value
+        The boolean equivalent of the string literal.
     """
     if isinstance(value, bool):
         return value
