@@ -285,6 +285,11 @@ def simplify_graph(  # noqa: C901, PLR0912
     """
     Simplify a graph's topology by removing interstitial nodes.
 
+    This algorithm is described in the journal article: Boeing, G. 2025.
+    "Topological Graph Simplification Solutions to the Street Intersection
+    Miscount Problem." Transactions in GIS, 29 (3), e70037.
+    https://doi.org/10.1111/tgis.70037
+
     This simplifies the graph's topology by removing all nodes that are not
     intersections or dead-ends, by creating an edge directly between the end
     points that encapsulate them while retaining the full geometry of the
@@ -454,6 +459,11 @@ def consolidate_intersections(
     """
     Consolidate intersections comprising clusters of nearby nodes.
 
+    This algorithm is described in the journal article: Boeing, G. 2025.
+    "Topological Graph Simplification Solutions to the Street Intersection
+    Miscount Problem." Transactions in GIS, 29 (3), e70037.
+    https://doi.org/10.1111/tgis.70037
+
     Merges nearby nodes and returns either their centroids or a rebuilt graph
     with consolidated intersections and reconnected edge geometries. The
     `tolerance` argument can be a single value applied to all nodes or
